@@ -1,23 +1,65 @@
 import logging
-from ase.db import connect
-import numpy as np
-from clease.tools import add_file_extension, sort_cf_names, get_ids
-from typing import Tuple, List, Dict, Set, Optional, Callable
+from typing import Tuple, List, Dict, Set, Optional, Sequence
 import sqlite3
+from abc import ABC, abstractmethod
 from itertools import combinations_with_replacement as cwr
+import numpy as np
+from ase.db import connect
+from clease import db_util
+from clease.tools import add_file_extension, sort_cf_names, get_ids
 
 logger = logging.getLogger(__name__)
 
-__all__ = ('InconsistentDataError', 'DataManager', 'CorrFuncEnergyDataManager',
-           'CorrelationFunctionGetter', 'CorrFuncVolumeDataManager',
-           'CorrelationFunctionGetterVolDepECI')
+__all__ = (
+    "InconsistentDataError",
+    "DataManager",
+    "CorrFuncEnergyDataManager",
+    "CorrelationFunctionGetter",
+    "CorrFuncVolumeDataManager",
+    "CorrelationFunctionGetterVolDepECI",
+    "FinalStructPropertyGetter",
+    "make_corr_func_data_manager",
+)
 
 
 class InconsistentDataError(Exception):
-    pass
+    """Data is inconsistent"""
 
 
-class DataManager(object):
+class PropertyGetter(ABC):
+    """Base class for getting a property from the database"""
+
+    def __init__(self, db_name: str):
+        self.db_name = db_name
+
+    @abstractmethod
+    def get_property(self, ids: Sequence[int]) -> np.ndarray:
+        """Return the properties of all structures which matches the criteria"""
+
+    def connect(self, **kwargs):
+        """Return an ASE connection to the database"""
+        return connect(self.db_name, **kwargs)
+
+
+class FeatureGetter(PropertyGetter, ABC):
+    """A base class for getting features, e.g. correlation functions"""
+
+    @property
+    @abstractmethod
+    def names(self) -> Sequence[str]:
+        """Return a name for each feature"""
+
+
+class TargetGetter(PropertyGetter, ABC):
+    """A base class for getting targets, e.g. energy per atom"""
+
+    @property
+    @abstractmethod
+    def name(self) -> str:
+        """Return the name of the target property"""
+
+
+class DataManager(ABC):
     """
     DataManager is a class for extracting data from CLEASE databases to be
     used to fit ECIs
@@ -32,8 +74,15 @@ class DataManager(object):
         self._feat_names = None
         self._target_name = None
 
-    def get_data(self, select_cond: List[tuple], feature_getter: Callable[[List[int]], np.ndarray],
-                 target_getter: Callable[[List[int]], np.ndarray]) -> Tuple[np.ndarray, np.ndarray]:
+    @abstractmethod
+    def get_data(self, select_cond: List[tuple]) -> Tuple[np.ndarray, np.ndarray]:
+        """
+        Return the design matrix X and the target data y
+        """
+
+    def _get_data_from_getters(
+        self, select_cond: List[tuple], feature_getter: FeatureGetter, target_getter: TargetGetter
+    ) -> Tuple[np.ndarray, np.ndarray]:
         """
         Return the design matrix X and the target data y
 
@@ -41,19 +90,14 @@ class DataManager(object):
             (e.g. [('converged', '='' True)])
 
         :param feature_getter:
-            Callable object that returns design matrix. It
-            also needs a method get_feature_names that returns a name of
-            each feature. The passed instance should take a list of IDs
-            as input argument and return a numpy array corresponding to
-            the design matrix
+            Instance of a FeatureGetter object that returns design matrix.
 
         :param target_getter:
-            Callable object that extracts the target value. The __call__
-            method takes a list of ids in the database and return a numpy
-            array with the target values (e.g. energy per atom)
+            Instance of a TargetGetter object that extracts the target value (e.g. energy per atom)
 
         Example:
 
+        >>> import clease
         >>> from clease.data_manager import (
         ... CorrelationFunctionGetter, FinalStructEnergyGetter,
         ... DataManager)
@@ -62,8 +106,8 @@ class DataManager(object):
         >>> from ase.calculators.emt import EMT
         >>> db_name = 'somedb.db'
         >>> db = connect(db_name)  # Make sure that the DB exists
-        >>> db.write(Atoms('Cu'), external_tables={
-        ... 'polynomial_cf': {'c0': 1.0}}, final_struct_id=2, converged=True)
+        >>> clease.db_util.new_row_with_single_table(db, Atoms('Cu'),
+        ...  'polynomial_cf', {'c0': 1.0}, final_struct_id=2, converged=True)
         1
         >>> final = Atoms('Cu')
         >>> final.calc = EMT()
@@ -82,8 +126,8 @@ class DataManager(object):
         ids = get_ids(select_cond, self.db_name)
 
         # Extract design matrix and the target values
-        cfm = feature_getter(ids)
-        target = target_getter(ids)
+        cfm = feature_getter.get_property(ids)
+        target = target_getter.get_property(ids)
 
         self._X = np.array(cfm, dtype=float)
         self._y = np.array(target)
@@ -93,12 +137,14 @@ class DataManager(object):
         nrows = self._X.shape[0]
         num_data = len(self._y)
         if nrows != num_data:
-            raise InconsistentDataError(f"Num. rows in deisgn matrix {nrows}."
-                                        f"Num. data points {num_data}\n"
-                                        "This is normally caused by a non-converged structure "
-                                        "being extracted from database. Check that all structures"
-                                        "extracted from DB using your query has a corresponding"
-                                        "final structure.")
+            raise InconsistentDataError(
+                f"Num. rows in deisgn matrix {nrows}."
+                f"Num. data points {num_data}\n"
+                "This is normally caused by a non-converged structure "
+                "being extracted from database. Check that all structures"
+                "extracted from DB using your query has a corresponding"
+                "final structure."
+            )
         return self._X, self._y
 
     def to_csv(self, fname: str):
@@ -118,7 +164,7 @@ class DataManager(object):
         """
         if self._X is None:
             return
-        fname = add_file_extension(fname, '.csv')
+        fname = add_file_extension(fname, ".csv")
         header = ",".join(self._feat_names) + f",{self._target_name}"
         data = np.hstack((self._X, np.reshape(self._y, (len(self._y), -1))))
         np.savetxt(fname, data, delimiter=",", header=header)
@@ -174,12 +220,14 @@ class CorrFuncEnergyDataManager(DataManager):
     :param order: Order of the correlation function. Default 1.
     """
 
-    def __init__(self,
-                 db_name: str,
-                 tab_name: str,
-                 cf_names: Optional[List[str]] = None,
-                 order: int = 1) -> None:
-        DataManager.__init__(self, db_name)
+    def __init__(
+        self,
+        db_name: str,
+        tab_name: str,
+        cf_names: Optional[List[str]] = None,
+        order: int = 1,
+    ) -> None:
+        super().__init__(db_name)
         self.tab_name = tab_name
         self.cf_names = cf_names
         self.order = order
@@ -192,13 +240,63 @@ class CorrFuncEnergyDataManager(DataManager):
         :param select_cond: List with select conditions for the database
             (e.g. [('converged', '=', True)])
         """
-        return DataManager.get_data(
-            self, select_cond,
+        # pylint: disable=arguments-differ
+        return self._get_data_from_getters(
+            select_cond,
             CorrelationFunctionGetter(self.db_name, self.tab_name, self.cf_names, order=self.order),
-            FinalStructEnergyGetter(self.db_name))
+            FinalStructEnergyGetter(self.db_name),
+        )
 
 
-class CorrelationFunctionGetter:
+class CorrFuncPropertyDataManager(DataManager):
+    """
+    CorrFuncFinalEnergyDataManager is a convenience class provided
+    to handle the standard case where the features are correlation functions
+    and the target is the user defined property (eg: bandgap, distortion etc)
+    which is in the databse as key-value-pair.
+
+    :param db_name: Name of the database being passed
+
+    :param cf_names: List with the correlation function names to extract
+
+    :param tab_name: Name of the table where the correlation functions are
+        stored
+
+    :param order: Order of the correlation function. Default 1.
+
+    :prop: User given property
+    """
+
+    def __init__(
+        self,
+        prop: str,
+        db_name: str,
+        tab_name: str,
+        cf_names: Optional[List[str]] = None,
+        order: int = 1,
+    ) -> None:
+        super().__init__(db_name)
+        self.tab_name = tab_name
+        self.cf_names = cf_names
+        self.order = order
+        self.prop = prop
+
+    def get_data(self, select_cond: List[tuple]) -> Tuple[np.ndarray, np.ndarray]:
+        """
+        Return X and y, where X is the design matrix containing correlation
+        functions and y is the DFT energy per atom.
+
+        :param select_cond: List with select conditions for the database
+            (e.g. [('converged', '=', True)])
+        """
+        return self._get_data_from_getters(
+            select_cond,
+            CorrelationFunctionGetter(self.db_name, self.tab_name, self.cf_names, order=self.order),
+            FinalStructPropertyGetter(self.db_name, self.prop),
+        )
+
+
+class CorrelationFunctionGetter(FeatureGetter):
     """
     CorrelationFunctionGetter is a class that extracts
     the correlation functions from an AtomsRow object
@@ -215,14 +313,12 @@ class CorrelationFunctionGetter:
     :param order: Order of the correlation function. Default is 1.
     """
 
-    def __init__(self,
-                 db_name: str,
-                 tab_name: str,
-                 cf_names: Optional[List[str]] = None,
-                 order: int = 1) -> None:
-        self.db_name = db_name
-        self.cf_names = cf_names
+    def __init__(
+        self, db_name: str, tab_name: str, cf_names: Optional[List[str]] = None, order: int = 1
+    ) -> None:
+        super().__init__(db_name)
         self.tab_name = tab_name
+        self.cf_names = cf_names
         self.order = order
 
     @property
@@ -267,7 +363,7 @@ class CorrelationFunctionGetter:
             common_cf = common_cf.intersection(v)
         return common_cf
 
-    def __call__(self, ids: List[int]) -> np.ndarray:
+    def get_property(self, ids: Sequence[int]) -> np.ndarray:
         """
         Extracts the design matrix associated with the database IDs. The first
         row in the matrix corresponds to the first item in ids, the second row
@@ -284,7 +380,8 @@ class CorrelationFunctionGetter:
 
         id_set = set(ids)
 
-        with connect(self.db_name) as db:
+        with self.connect() as db:
+            self._check_version(db, *ids)
             cur = db.connection.cursor()
             cur.execute(sql)
 
@@ -314,7 +411,7 @@ class CorrelationFunctionGetter:
             raise InconsistentDataError(msg)
 
         if self.cf_names is None:
-            self.cf_names = set([v for item in id_cf_names.values() for v in item])
+            self.cf_names = set(v for item in id_cf_names.values() for v in item)
             self.cf_names = list(self.cf_names)
             self.cf_names = sort_cf_names(self.cf_names)
 
@@ -351,14 +448,21 @@ class CorrelationFunctionGetter:
                 for i in comb:
                     X[:, 0] *= cf_matrix[:, i]
                 cf_matrix = np.hstack((cf_matrix, X))
-                name = '*'.join(self.cf_names[i] for i in comb)
+                name = "*".join(self.cf_names[i] for i in comb)
 
                 # Add the new to the list of cf names
                 self.cf_names.append(name)
         return cf_matrix
 
+    def _check_version(self, connection, *ids: Sequence[int]) -> None:
+        if db_util.require_reconfigure_table(connection, self.tab_name, *ids):
+            raise db_util.OutOfDateTable(
+                "An out of date correlation function table was found. "
+                'Please reconfigure your database, e.g. using "clease.reconfigure(settings)".'
+            )
 
-class FinalStructEnergyGetter(object):
+
+class FinalStructEnergyGetter(TargetGetter):
     """
     FinalStructEnergyGetter is a callable class that returns the final energy
     (typically after structure relaxation) corresponding to the passed
@@ -367,14 +471,11 @@ class FinalStructEnergyGetter(object):
     :param db_name: Name of the database
     """
 
-    def __init__(self, db_name: str) -> None:
-        self.db_name = db_name
-
     @property
     def name(self):
         return "E_DFT (eV/atom)"
 
-    def __call__(self, ids: List[int]) -> np.ndarray:
+    def get_property(self, ids: Sequence[int]) -> np.ndarray:
         """
         Extract the final energy of the ids passed. In the returned array, the
         first energy corresponds to the first item in ids, the second energy
@@ -388,7 +489,7 @@ class FinalStructEnergyGetter(object):
         # Map beetween the initial structure and the index in the id list
         init_struct_idx = {idx: i for i, idx in enumerate(ids)}
 
-        with connect(self.db_name) as db:
+        with self.connect() as db:
             cur = db.connection.cursor()
             cur.execute(sql)
             final_struct_ids = []
@@ -416,21 +517,73 @@ class FinalStructEnergyGetter(object):
         return energies
 
 
-class FinalVolumeGetter(object):
+class FinalStructPropertyGetter(TargetGetter):
+    """
+    FinalStructPropertyGetter is a class that returns the user defined property
+    value corresponding to the passed AtomsRow object.
+    The user defined property should be located in the *final* atoms row.
+
+    :param db_name: Name of the database
+    """
+
+    def __init__(self, db_name: str, prop: str) -> None:
+        super().__init__(db_name)
+        self.prop = prop
+
+    @property
+    def name(self):
+        return f"Property: {self.prop}"
+
+    def get_property(self, ids: Sequence[int]) -> np.ndarray:
+        """
+        Extract the property of the ids passed.
+
+        :param ids: Database ids of initial structures
+        """
+        sql = "SELECT value, id FROM number_key_values "
+        sql += "WHERE key='final_struct_id'"
+        id_set = set(ids)
+        # Map beetween the initial structure and the index in the id list
+        init_struct_idx = {idx: i for i, idx in enumerate(ids)}
+
+        with self.connect() as db:
+            cur = db.connection.cursor()
+            cur.execute(sql)
+            final_struct_ids = []
+
+            # Map the between final struct id and initial struct id
+            init_struct_ids = {}
+            for final_id, init_id in cur.fetchall():
+                if init_id in id_set:
+                    final_struct_ids.append(final_id)
+                    init_struct_ids[final_id] = init_id
+
+            final_struct_ids = set(final_struct_ids)
+            sql = f"SELECT id, value FROM number_key_values WHERE key='{self.prop}'"
+            cur.execute(sql)
+            prop_values = np.zeros(len(final_struct_ids))
+
+            # Populate the property array
+            for final_id, prop_value in cur.fetchall():
+                if final_id in final_struct_ids:
+                    init_id = init_struct_ids[final_id]
+                    idx = init_struct_idx[init_id]
+                    prop_values[idx] = prop_value
+        return prop_values
+
+
+class FinalVolumeGetter(TargetGetter):
     """
     Class that extracts the final volume per atom of the relaxed structure
 
     :param db_name: Name of the database
     """
 
-    def __init__(self, db_name: str) -> None:
-        self.db_name = db_name
-
     @property
     def name(self):
         return "Volume (A^3)"
 
-    def __call__(self, ids: List[int]) -> np.ndarray:
+    def get_property(self, ids: Sequence[int]) -> np.ndarray:
         """
         Extracts the final volume of the ids passed. In the returned array,
         the first volume corresponds to the first item in ids, the second
@@ -444,7 +597,7 @@ class FinalVolumeGetter(object):
 
         init_ids = {}
         id_idx = {db_id: i for i, db_id in enumerate(ids)}
-        with connect(self.db_name) as db:
+        with self.connect() as db:
             cur = db.connection.cursor()
             cur.execute(query)
             final_struct_ids = []
@@ -461,7 +614,7 @@ class FinalVolumeGetter(object):
             num_atoms = extract_num_atoms(cur, id_set)
 
             final_struct_ids = set(final_struct_ids)
-            query = 'SELECT id, volume FROM systems'
+            query = "SELECT id, volume FROM systems"
             cur.execute(query)
             volumes = np.zeros(len(init_ids))
 
@@ -496,12 +649,14 @@ class CorrFuncVolumeDataManager(DataManager):
     :param order: Order of the correlation functions. Default 1.
     """
 
-    def __init__(self,
-                 db_name: str,
-                 tab_name: str,
-                 cf_names: Optional[List[str]] = None,
-                 order: int = 1) -> None:
-        DataManager.__init__(self, db_name)
+    def __init__(
+        self,
+        db_name: str,
+        tab_name: str,
+        cf_names: Optional[List[str]] = None,
+        order: int = 1,
+    ) -> None:
+        super().__init__(db_name)
         self.tab_name = tab_name
         self.cf_names = cf_names
         self.order = order
@@ -517,10 +672,12 @@ class CorrFuncVolumeDataManager(DataManager):
             List with select conditions for the database
             (e.g. [('converged', '=', True)])
         """
-        return DataManager.get_data(
-            self, select_cond,
+        # pylint: disable=arguments-differ
+        return self._get_data_from_getters(
+            select_cond,
             CorrelationFunctionGetter(self.db_name, self.tab_name, self.cf_names, order=self.order),
-            FinalVolumeGetter(self.db_name))
+            FinalVolumeGetter(self.db_name),
+        )
 
 
 def extract_num_atoms(cur: sqlite3.Cursor, ids: Set[int]) -> Dict[int, int]:
@@ -569,21 +726,21 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
         in the correlation function. Default is 1.
     """
 
-    def __init__(self,
-                 db_name: str,
-                 tab_name: str,
-                 cf_names: List[str],
-                 order: Optional[int] = 0,
-                 properties: Tuple[str] = ('energy', 'pressure'),
-                 cf_order: int = 1) -> None:
-        self.db_name = db_name
+    def __init__(
+        self,
+        db_name: str,
+        tab_name: str,
+        cf_names: List[str],
+        order: Optional[int] = 0,
+        properties: Tuple[str] = ("energy", "pressure"),
+        cf_order: int = 1,
+    ) -> None:
+        super().__init__(db_name)
         self.tab_name = tab_name
         self.order = order
         self.cf_names = cf_names
         self.properties = properties
         self.cf_order = cf_order
-        self._X = None
-        self._y = None
         self._groups = []
 
     def build(self, ids: List[int]) -> np.ndarray:
@@ -593,20 +750,20 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
 
         :param ids: List of ids to take into account
         """
-        cf_getter = CorrelationFunctionGetter(self.db_name,
-                                              self.tab_name,
-                                              self.cf_names,
-                                              order=self.cf_order)
-        cf = cf_getter(ids)
+        # pylint: disable=too-many-statements, too-many-locals
+        cf_getter = CorrelationFunctionGetter(
+            self.db_name, self.tab_name, self.cf_names, order=self.cf_order
+        )
+        cf = cf_getter.get_property(ids)
 
         volume_getter = FinalVolumeGetter(self.db_name)
-        volumes = volume_getter(ids)
+        volumes = volume_getter.get_property(ids)
 
         energy_getter = FinalStructEnergyGetter(self.db_name)
-        energies = energy_getter(ids)
+        energies = energy_getter.get_property(ids)
 
         target_values = [energies]
-        target_val_names = ['energy']
+        target_val_names = ["energy"]
 
         cf_vol_dep = np.zeros((cf.shape[0], (self.order + 1) * cf.shape[1]))
         counter = 0
@@ -623,7 +780,7 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
                 self._feat_names.append(cf_getter.names[col] + f"_V{power}")
 
         # Add pressure data. P = dE/dV = 0 (we assume relaxed structures)
-        if 'pressure' in self.properties:
+        if "pressure" in self.properties:
             pressure_cf = np.zeros_like(cf_vol_dep)
             counter = 0
 
@@ -633,13 +790,13 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
             # to be zero
             for col in range(0, cf.shape[1]):
                 for p in range(self.order + 1):
-                    pressure_cf[:, counter] = p * cf[:, col] * volumes**(p - 1)
+                    pressure_cf[:, counter] = p * cf[:, col] * volumes ** (p - 1)
                     counter += 1
 
             # Update the full design matrix and the target values
             cf_vol_dep = np.vstack((cf_vol_dep, pressure_cf))
             target_values.append(np.zeros(pressure_cf.shape[0]))
-            target_val_names.append('pressure')
+            target_val_names.append("pressure")
 
             # All data points have a pressure, the groups just repeats
             # themselves
@@ -648,9 +805,9 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
         id_row = {db_id: i for i, db_id in enumerate(ids)}
 
         # Add bulk modulus data. B = V*d^2E/dV^2
-        if 'bulk_mod' in self.properties:
-            bulk_mod = self._extract_key(set(ids), 'bulk_mod')
-            bulk_mod_rows = [id_row[k] for k in bulk_mod.keys()]
+        if "bulk_mod" in self.properties:
+            bulk_mod = self._extract_key(set(ids), "bulk_mod")
+            bulk_mod_rows = [id_row[key] for key in bulk_mod]
             bulk_mod_cf = np.zeros((len(bulk_mod), cf_vol_dep.shape[1]))
 
             counter = 0
@@ -662,20 +819,19 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
             for col in range(0, cf.shape[1]):
                 for power in range(self.order + 1):
                     bulk_mod_cf[:, counter] = vols * cf[bulk_mod_rows, col]
-                    bulk_mod_cf[:, counter] *= power * \
-                        (power - 1) * vols**(power - 2)
+                    bulk_mod_cf[:, counter] *= power * (power - 1) * vols ** (power - 2)
                     counter += 1
 
             # Update the full design matrix as well as the target values
             cf_vol_dep = np.vstack((cf_vol_dep, bulk_mod_cf))
             target_values.append(bulk_mod.values())
-            target_val_names.append('bulk_mod')
+            target_val_names.append("bulk_mod")
             self._groups += [self._groups[r] for r in bulk_mod_rows]
 
         # Add the pressure derivative of the bulk modulus (dB/dP)
-        if 'dBdP' in self.properties:
-            dBdP = self._extract_key(set(ids), 'dBdP')
-            dBdP_rows = [id_row[k] for k in dBdP.keys()]
+        if "dBdP" in self.properties:
+            dBdP = self._extract_key(set(ids), "dBdP")
+            dBdP_rows = [id_row[key] for key in dBdP]
             dBdP_cf = np.zeros((len(dBdP), cf_vol_dep.shape[1]))
             dBdP = np.array(list(dBdP.values()))
 
@@ -684,19 +840,19 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
             for col in range(cf.shape[1]):
                 for power in range(self.order + 1):
                     # Double derivative of the energy
-                    dE2 = power * (power - 1) * \
-                        cf[dBdP_rows, col] * vols**(power - 2)
+                    dE2 = power * (power - 1) * cf[dBdP_rows, col] * vols ** (power - 2)
 
                     # Third derivative of the energy
-                    dE3 = power*(power-1)*(power-2)*cf[dBdP_rows, col] * \
-                        vols**(power-3)
+                    dE3 = (
+                        power * (power - 1) * (power - 2) * cf[dBdP_rows, col] * vols ** (power - 3)
+                    )
                     dBdP_cf[:, counter] = (1.0 + dBdP) * dE2 + vols * dE3
                     counter += 1
 
             # Update the full design matrix
             cf_vol_dep = np.vstack((cf_vol_dep, dBdP_cf))
             target_values.append(np.zeros(len(dBdP)))
-            target_val_names.append('dBdP')
+            target_val_names.append("dBdP")
             self._groups += [self._groups[r] for r in dBdP_rows]
 
         # Assign the global design matrix to the attribute _X, the vector with
@@ -704,7 +860,7 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
         # joining all subnames
         self._X = cf_vol_dep
         self._y = np.array([x for values in target_values for x in values])
-        self._target_name = '-'.join(target_val_names)
+        self._target_name = "-".join(target_val_names)
 
     def _extract_key(self, ids: Set[int], key: str) -> Dict[int, float]:
         """
@@ -739,7 +895,6 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
             condition.
         """
         ids = get_ids(select_cond, self.db_name)
-
         self.build(ids)
         return self._X, self._y
 
@@ -748,3 +903,13 @@ class CorrelationFunctionGetterVolDepECI(DataManager):
         Return the group of each rows.
         """
         return self._groups
+
+
+def make_corr_func_data_manager(
+    prop: str, db_name: str, tab_name: str, cf_names: Sequence[str], **kwargs
+) -> DataManager:
+    """Helper function for creating a correlation function data manager"""
+    if prop.lower() == "energy":
+        return CorrFuncEnergyDataManager(db_name, tab_name, cf_names, **kwargs)
+    # Assume it's a property data manager
+    return CorrFuncPropertyDataManager(prop, db_name, tab_name, cf_names, **kwargs)
